# Frameworks API Reference

This page documents the API for working with framework configurations.

## Discovery Functions

::: agentci.client_config.frameworks.parser.discover_frameworks

::: agentci.client_config.frameworks.parser.parse_framework_config_toml

## Schema Models

### FrameworkConfig

::: agentci.client_config.frameworks.schema.FrameworkConfig

### FrameworkMetadata

::: agentci.client_config.frameworks.schema.FrameworkMetadata

### AgentConfig

::: agentci.client_config.frameworks.schema.AgentConfig

### ToolConfig

::: agentci.client_config.frameworks.schema.ToolConfig

## Type Enums

### AgentType

::: agentci.client_config.frameworks.schema.AgentType

### ToolType

::: agentci.client_config.frameworks.schema.ToolType

## Argument Models

### AgentDiscoveryArgs

::: agentci.client_config.frameworks.schema.AgentDiscoveryArgs

### AgentExecutionArgs

::: agentci.client_config.frameworks.schema.AgentExecutionArgs

### ExecutionConfig

::: agentci.client_config.frameworks.schema.ExecutionConfig

### NameExtraction

::: agentci.client_config.frameworks.schema.NameExtraction
